@@ -3,6 +3,7 @@ from unittest import mock
 
 from django.db import models
 from django.test import TestCase, override_settings
+from django.utils.datastructures import MultiValueDict
 
 from django_filters.exceptions import FieldLookupError
 from django_filters.filters import (
@@ -19,7 +20,11 @@ from django_filters.filters import (
     NumberFilter,
     UUIDFilter,
 )
-from django_filters.filterset import FILTER_FOR_DBFIELD_DEFAULTS, FilterSet
+from django_filters.filterset import (
+    FILTER_FOR_DBFIELD_DEFAULTS,
+    FilterSet,
+    filterset_factory,
+)
 from django_filters.widgets import BooleanWidget
 
 from .models import (
@@ -52,10 +57,6 @@ class HelperMethodsTests(TestCase):
     def test_filters_for_model(self):
         pass
 
-    @unittest.skip("todo")
-    def test_filterset_factory(self):
-        pass
-
 
 class DbFieldDefaultFiltersTests(TestCase):
     def test_expected_db_fields_get_filters(self):
@@ -520,7 +521,7 @@ class FilterSetClassCreationTests(TestCase):
                     model = User
                     fields = {"username": ["flub"]}
 
-    def test_meta_exlude_with_declared_and_declared_wins(self):
+    def test_meta_exclude_with_declared_and_declared_wins(self):
         class F(FilterSet):
             username = CharFilter()
 
@@ -534,7 +535,7 @@ class FilterSetClassCreationTests(TestCase):
             list(F.base_filters), ["title", "average_rating", "username"]
         )
 
-    def test_meta_fields_and_exlude_and_exclude_wins(self):
+    def test_meta_fields_and_exclude_and_exclude_wins(self):
         class F(FilterSet):
             username = CharFilter()
 
@@ -547,7 +548,7 @@ class FilterSetClassCreationTests(TestCase):
         self.assertEqual(len(F.base_filters), 2)
         self.assertListEqual(list(F.base_filters), ["username", "price"])
 
-    def test_meta_exlude_with_no_fields(self):
+    def test_meta_exclude_with_no_fields(self):
         class F(FilterSet):
             class Meta:
                 model = Book
@@ -715,6 +716,73 @@ class FilterSetClassCreationTests(TestCase):
             "f5": CharFilter,
         }
 
+    def test_filterset_factory(self):
+        filterset = filterset_factory(Article)
+        self.assertEqual(list(filterset.base_filters), ["name", "published", "author"])
+
+    def test_filterset_factory_fields(self):
+        filterset = filterset_factory(Article, fields=["name"])
+        self.assertEqual(list(filterset.base_filters), ["name"])
+
+    def test_filterset_factory_base_filter(self):
+        class FilterSetBase(FilterSet):
+            f1 = CharFilter()
+            f2 = CharFilter()
+
+        filterset = filterset_factory(Article, filterset=FilterSetBase)
+        self.assertEqual(list(filterset.base_filters), ["name", "published", "author", "f1", "f2"])
+
+    def test_filterset_factory_base_filter_fields(self):
+        class FilterSetBase(FilterSet):
+            f1 = CharFilter()
+            f2 = CharFilter()
+
+        filterset = filterset_factory(Article, filterset=FilterSetBase, fields=["name"])
+        self.assertEqual(list(filterset.base_filters), ["name", "f1", "f2"])
+
+    def test_filterset_factory_base_filter_meta_fields(self):
+        class FilterSetBase(FilterSet):
+            class Meta:
+                fields = ["name"]
+            f1 = CharFilter()
+            f2 = CharFilter()
+
+        filterset = filterset_factory(Article, filterset=FilterSetBase)
+        self.assertEqual(list(filterset.base_filters), ["name", "f1", "f2"])
+
+    def test_filterset_factory_base_filter_fields_and_meta_fields(self):
+        class FilterSetBase(FilterSet):
+            class Meta:
+                fields = ["name"]
+            f1 = CharFilter()
+            f2 = CharFilter()
+
+        filterset = filterset_factory(Article, filterset=FilterSetBase, fields=["author"])
+        self.assertEqual(list(filterset.base_filters), ["author", "f1", "f2"])
+
+    def test_filterset_factory_base_filter_meta_inheritance_filter_overrides(self):
+        class FilterSetBase(FilterSet):
+            class Meta:
+                filter_overrides = {
+                    models.CharField: {
+                        "filter_class": BooleanFilter,
+                    },
+                }
+
+        filterset = filterset_factory(Article, FilterSetBase)
+
+        f = Article._meta.get_field("author")
+        result, params = filterset.filter_for_lookup(f, "isnull")
+        self.assertEqual(result, BooleanFilter)
+
+    def test_filterset_factory_base_filter_meta_inheritance_exclude(self):
+        class FilterSetBase(FilterSet):
+            class Meta:
+                exclude = ["published"]
+
+        filterset = filterset_factory(Article, FilterSetBase)
+        self.assertEqual(list(filterset.base_filters), ["name", "author"])
+
 
 class FilterSetInstantiationTests(TestCase):
     class F(FilterSet):
@@ -746,6 +814,10 @@ class FilterSetInstantiationTests(TestCase):
         f = self.F(request=m)
         self.assertEqual(f.request, m)
 
+    def test_creating_with_no_data_default(self):
+        f = self.F()
+        self.assertIsInstance(f.data, MultiValueDict)
+
 
 class FilterSetQuerysetTests(TestCase):
     class F(FilterSet):
